==> physx-jni-0.4.1-sources.jar: physx/vehicle/PxVehicleChassisData.java <==
package physx.vehicle;

import physx.NativeObject;
import physx.common.PxVec3;

public class PxVehicleChassisData extends NativeObject {

    public static PxVehicleChassisData wrapPointer(long address) {
        return address != 0L ? new PxVehicleChassisData(address) : null;
    }
    
    protected PxVehicleChassisData(long address) {
        super(address);
    }

    // Constructors

    public PxVehicleChassisData() {
        address = _PxVehicleChassisData();
    }
    private static native long _PxVehicleChassisData();

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMMOI() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxVec3.wrapPointer(_getMMOI(address));
    }
    private static native long _getMMOI(long address);

    /**
     * @param value WebIDL type: {@link PxVec3} [Value]
     */
    public void setMMOI(PxVec3 value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMMOI(address, value.getAddress());
    }
    private static native void _setMMOI(long address, long value);

    /**
     * @return WebIDL type: float
     */
    public float getMMass() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getMMass(address);
    }
    private static native float _getMMass(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMMass(float value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMMass(address, value);
    }
    private static native void _setMMass(long address, float value);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMCMOffset() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxVec3.wrapPointer(_getMCMOffset(address));
    }
    private static native long _getMCMOffset(long address);

    /**
     * @param value WebIDL type: {@link PxVec3} [Value]
     */
    public void setMCMOffset(PxVec3 value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setMCMOffset(address, value.getAddress());
    }
    private static native void _setMCMOffset(long address, long value);

}

==> physx-jni-0.4.18-sources.jar: physx/vehicle/PxVehicleChassisData.java <==
package physx.vehicle;

import physx.NativeObject;
import physx.common.PxVec3;

public class PxVehicleChassisData extends NativeObject {

    public static PxVehicleChassisData wrapPointer(long address) {
        return address != 0L ? new PxVehicleChassisData(address) : null;
    }
    
    protected PxVehicleChassisData(long address) {
        super(address);
    }

    // Constructors

    public PxVehicleChassisData() {
        address = _PxVehicleChassisData();
    }
    private static native long _PxVehicleChassisData();

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMMOI() {
        checkNotNull();
        return PxVec3.wrapPointer(_getMMOI(address));
    }
    private static native long _getMMOI(long address);

    /**
     * @param value WebIDL type: {@link PxVec3} [Value]
     */
    public void setMMOI(PxVec3 value) {
        checkNotNull();
        _setMMOI(address, value.getAddress());
    }
    private static native void _setMMOI(long address, long value);

    /**
     * @return WebIDL type: float
     */
    public float getMMass() {
        checkNotNull();
        return _getMMass(address);
    }
    private static native float _getMMass(long address);

    /**
     * @param value WebIDL type: float
     */
    public void setMMass(float value) {
        checkNotNull();
        _setMMass(address, value);
    }
    private static native void _setMMass(long address, float value);

    /**
     * @return WebIDL type: {@link PxVec3} [Value]
     */
    public PxVec3 getMCMOffset() {
        checkNotNull();
        return PxVec3.wrapPointer(_getMCMOffset(address));
    }
    private static native long _getMCMOffset(long address);

    /**
     * @param value WebIDL type: {@link PxVec3} [Value]
     */
    public void setMCMOffset(PxVec3 value) {
        checkNotNull();
        _setMCMOffset(address, value.getAddress());
    }
    private static native void _setMCMOffset(long address, long value);

}
